@@ -1,4 +1,4 @@
-# Copyright (C) 2020 Brodie Gaslam
+# Copyright (C) 2021 Brodie Gaslam
 #
 # This file is part of "diffobj - Diffs for R Objects"
 #
@@ -76,7 +76,8 @@ detect_2d_guides <- function(txt) {
   first.spaces <- grep("^\\s+\\S+", txt)
 
   if(length(first.spaces)) {
-    # Now look for data
+    # Now look for data; space.rows are rows that start with spaces, and thus
+    # likely contain the column headers.
 
     first.space <- min(first.spaces)
     space.rows <-
@@ -106,18 +107,21 @@ detect_2d_guides <- function(txt) {
         # print gets truncated; should allow last in sequence to have fewer rows,
         # but we don't do that yet...
 
-        seq.diffs <- abs(apply(seq.dat, 1L, diff))
-        valid.rep <- max(
-          which(
-            cumsum(colSums(cbind(integer(2L), seq.diffs))) == 0L
-          ),
-          0L
-        )
-        if(valid.rep) {
-          res <- which(
-            rep(rep(c(TRUE, FALSE), valid.rep), seq.dat[seq_len(valid.rep * 2L)])
-          ) + head.row - 1L
-  } } } }
+        valid.grps <- colSums(seq.dat - seq.dat[,1L] == 0L) == 2L
+        if(any(valid.grps)) {
+          # Figure out which rows the headers correspond to by cumsuming the
+          # header and non-header rows, and then adding the initial offset.
+          res <- array(cumsum(seq.dat), dim=dim(seq.dat))[1L, valid.grps] +
+            head.row - 1L
+          # If there is more than one row for each header, expand out the header
+          if(seq.dat[1L, 1L] > 1L)
+            # sequence only gained `from` param in R4.x, so this is our
+            # "backport"
+            res <- base::unname(
+              sequence(seq.dat[1L,]) + rep(res - seq.dat[1L,], seq.dat[1L,])
+            )
+        }
+  } } }
   res
 }
 # Definitely approximate matching, we are lazy in matching the `$` versions
